package gymcard

import (
	"errors"
	"spaceofcheng/services/models/gymcard"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service"
	"spaceofcheng/services/utils"
)

// GymcardServ 系统处理
type GymcardServ struct {
	ctx *utils.Context
	dao *gymcard.GymcardDAO
}

// NewGymcardServ 初始化
func NewGymcardServ(ctx *utils.Context) *GymcardServ {
	return &GymcardServ{
		ctx: ctx,
		dao: gymcard.NewGymcardDAO(ctx),
	}
}
func (s *GymcardServ) GetGymcardList(caseid string, page, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	gymcard, err := s.dao.GetGymcard(caseid, page, pageSize)
	if err != nil {
		utils.LogError("获取健身卡列表失败：" + err.Error())
		return nil, errors.New("获取健身卡列表失败")
	}
	total, err := s.dao.GetGymcardCount(caseid)
	if err != nil {
		utils.LogError("获取健身卡列表失败：" + err.Error())
		return nil, errors.New("获取健身卡列表失败")
	}
	return map[string]interface{}{
		"list":     gymcard,
		"pageSize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, nil
}
func (s *GymcardServ) GetCustomerGymBycustomerId(customerId string, page, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	customerGym, err := s.dao.GetCustomerGymByCustomerId(customerId, page, pageSize)
	if err != nil {
		utils.LogError("获取健身卡列表失败：" + err.Error())
		return nil, errors.New("获取健身卡列表失败")
	}
	total, err := s.dao.GetCustomerGymCountByCustomerId(customerId)
	if err != nil {
		utils.LogError("获取健身卡列表失败：" + err.Error())
		return nil, errors.New("获取健身卡列表失败")
	}
	return map[string]interface{}{
		"list":     customerGym,
		"pageSize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, nil
}
func (s *GymcardServ) GetGymcardDetailByIdZ(gymcardId string) (*gymcard.Gymcard, error) {
	gymcard, err := s.dao.GetGymcardById(gymcardId)
	if err != nil {
		utils.LogError("获取健身卡详情失败" + err.Error())
		return nil, errors.New("获取健身卡详情失败")
	}
	return gymcard, nil
}

func (s *GymcardServ) SaveGymcard(newGym gymcard.Gymcard) (*gymcard.Gymcard, error) {
	var newGymCard model.TaGymCard
	var cardGym model.TaGymCard
	var err error
	if newGym.GymCardId == "" {
		newGymCard = newGym.TaGymCard
		cardGym, err = s.dao.AddGymcard(newGymCard)
		err = s.dao.AddGymcardImg(newGym.GymCardId, newGym.CardImageUrl)
		newGym.TaGymCard = cardGym
		err = s.dao.AddGymcardShare(newGym.GymCardId, newGym.CardShareInfo, newGym.CardUseRule, newGym.CardUseInstruction)
	} else {
		err = s.dao.EditGymcardImg(newGym.GymCardId, newGym.CardImageUrl)
		err = s.dao.EditGymcardShare(newGym.GymCardId, newGym.CardShareInfo, newGym.CardUseRule, newGym.CardUseInstruction)
	}
	if err != nil {
		utils.LogError("保存健身卡信息失败" + err.Error())
		return nil, errors.New("保存健身卡信息失败")
	}
	return &newGym, nil
}

func (s *GymcardServ) SendGymCardToUser(customerId, gymcardId string) (*model.TaCustomerGym, error) {
	var customerGym *model.TaCustomerGym
	gymCard, err := s.dao.GetGymcardById(gymcardId)
	if err != nil {
		utils.LogError("发送游泳健身卡给客户失败" + err.Error())
		return nil, errors.New("发送游泳健身卡给客户失败")
	}
	customerGym, err = s.dao.SendGymcardToCustomer(gymCard, customerId)
	if err != nil {
		utils.LogError("发送游泳健身卡给客户失败" + err.Error())
		return nil, errors.New("发送游泳健身卡给客户失败")
	}
	return customerGym, nil

}
